# Benchling API Client

A Python 3.8+ API Client for the [Benchling](https://www.benchling.com/) platform automatically generated from OpenAPI specs.

*Important!* This is an unsupported pre-release not suitable for production use.

_Please reach out to your customer support representative if you would be interested in a public version!_